#ifndef SYMFONIEFILETYPESDIALOG_H
#define SYMFONIEFILETYPESDIALOG_H

#include <QDialog>

class QStringList;
class QCheckBox;

namespace Ui {
    class SymfonieFileTypesDialog;
}

class SymfonieFileTypesDialog : public QDialog {
    Q_OBJECT
public:
    SymfonieFileTypesDialog(QWidget *parent = 0);
    ~SymfonieFileTypesDialog();
    static QStringList serializePattern(QString str);
    static QStringList getSavedFilterList();
    void updateCheckedFileTypes();

Q_SIGNALS:
    void fileTypesChanged(QStringList);

protected:
    void changeEvent(QEvent *e);


private Q_SLOTS:
    void finishedSlot(int);

private:
    Ui::SymfonieFileTypesDialog *ui;
    QStringList fileTypeList;
    QList<QCheckBox*> fileTypeCbList;
};

#endif // SYMFONIEFILETYPESDIALOG_H
